[libpng17] Avoid potential overflow of the PNG_IMAGE_SIZE macro.  This macro

is not used within libpng, but is used in some of the examples.
diff --git a/ANNOUNCE b/ANNOUNCE
index cdf6949..60d3c3e 100644
--- a/ANNOUNCE
+++ b/ANNOUNCE
@@ -1,5 +1,5 @@
 
-Libpng 1.7.0beta81 - June 8, 2016
+Libpng 1.7.0beta81 - June 11, 2016
 
 This is not intended to be a public release.  It will be replaced
 within a few weeks by a public version or by another test version.
@@ -1290,7 +1290,7 @@
       unreachable code in pz_default_settings and eliminated a spurious
       warning in pngcp for small files.
 
-Version 1.7.0beta81 [June 8, 2016]
+Version 1.7.0beta81 [June 11, 2016]
   Check for CLOCK_PROCESS_CPUTIME_ID when building /contrib/libtests/timepng.
     Otherwise it does not build on platforms that don't supply clock_gettime().
   Add check for clock_gettime() in Makefile.am and configure.ac
@@ -1377,6 +1377,8 @@
   Removed png_struct::flags which is no longer used.
   Fixed implementations of png_app_error() and png_app_warning() which
     previously were swapped.
+  Avoid potential overflow of the PNG_IMAGE_SIZE macro.  This macro
+    is not used within libpng, but is used in some of the examples.
 
 Send comments/corrections/commendations to png-mng-implement at lists.sf.net
 (subscription required; visit
diff --git a/CHANGES b/CHANGES
index de1eac9..e30260d 100644
--- a/CHANGES
+++ b/CHANGES
@@ -5590,7 +5590,7 @@
       unreachable code in pz_default_settings and eliminated a spurious
       warning in pngcp for small files.
 
-Version 1.7.0beta81 [June 8, 2016]
+Version 1.7.0beta81 [June 11, 2016]
   Check for CLOCK_PROCESS_CPUTIME_ID when building /contrib/libtests/timepng.
     Otherwise it does not build on platforms that don't supply clock_gettime().
   Add check for clock_gettime() in Makefile.am and configure.ac
@@ -5677,6 +5677,8 @@
   Removed png_struct::flags which is no longer used.
   Fixed implementations of png_app_error() and png_app_warning() which
     previously were swapped.
+  Avoid potential overflow of the PNG_IMAGE_SIZE macro.  This macro
+    is not used within libpng, but is used in some of the examples.
 
 Send comments/corrections/commendations to png-mng-implement at lists.sf.net
 (subscription required; visit
diff --git a/png.h b/png.h
index e41a49d..7d51811 100644
--- a/png.h
+++ b/png.h
@@ -1,7 +1,7 @@
 
 /* png.h - header file for PNG reference library
  *
  * libpng version 1.7.0beta81, June 7, 2016
  *
  * Copyright (c) 1998-2002,2004,2006-2016 Glenn Randers-Pehrson
  * (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
@@ -12,7 +12,7 @@
  * Authors and maintainers:
  *   libpng versions 0.71, May 1995, through 0.88, January 1996: Guy Schalnat
  *   libpng versions 0.89, June 1996, through 0.96, May 1997: Andreas Dilger
  *   libpng versions 0.97, January 1998, through 1.7.0beta81, June 7, 2016:
  *     Glenn Randers-Pehrson.
  *   See also "Contributing Authors", below.
  */
@@ -25,7 +25,7 @@
  *
  * This code is released under the libpng license.
  *
  * libpng versions 1.0.7, July 1, 2000, through 1.7.0beta81, June 7, 2016, are
  * Copyright (c) 2000-2002, 2004, 2006-2016 Glenn Randers-Pehrson, are
  * derived from libpng-1.0.6, and are distributed according to the same
  * disclaimer and license as libpng-1.0.6 with the following individuals
@@ -217,7 +217,7 @@
  * Y2K compliance in libpng:
  * =========================
  *
- *    June 7, 2016
+ *    June 11, 2016
  *
  *    Since the PNG Development group is an ad-hoc body, we can't make
  *    an official declaration.
@@ -287,7 +287,7 @@
 /* Version information for png.h - this should match the version in png.c */
 #define PNG_LIBPNG_VER_STRING "1.7.0beta81"
 #define PNG_HEADER_VERSION_STRING \
-     " libpng version 1.7.0beta81 - June 7, 2016\n"
+     " libpng version 1.7.0beta81 - June 11, 2016\n"
 
 #define PNG_LIBPNG_VER_SONUM   17
 #define PNG_LIBPNG_VER_DLLNUM  17
@@ -1,7 +1,7 @@
 /* png.h - header file for PNG reference library
  *
- * libpng version 1.7.0beta81, June 7, 2016
+ * libpng version 1.7.0beta81, June 11, 2016
  *
  * Copyright (c) 1998-2002,2004,2006-2016 Glenn Randers-Pehrson
@@ -12,7 +12,7 @@
  *   libpng versions 0.71, May 1995, through 0.88, January 1996: Guy Schalnat
  *   libpng versions 0.89, June 1996, through 0.96, May 1997: Andreas Dilger
- *   libpng versions 0.97, January 1998, through 1.7.0beta81, June 7, 2016:
+ *   libpng versions 0.97, January 1998, through 1.7.0beta81, June 11, 2016:
  *     Glenn Randers-Pehrson.
  *   See also "Contributing Authors", below.
@@ -25,7 +25,7 @@
  * This code is released under the libpng license.
  *
- * libpng versions 1.0.7, July 1, 2000, through 1.7.0beta81, June 7, 2016, are
+ * libpng versions 1.0.7, July 1, 2000, through 1.7.0beta81, June 11, 2016, are
  * Copyright (c) 2000-2002, 2004, 2006-2016 Glenn Randers-Pehrson, are
  * derived from libpng-1.0.6, and are distributed according to the same